---
title: "Key tasks for AI in MSK imaging"
author: "Jean Feydy"
institute: ""
topic: ""
theme: "metropolis"
colortheme:
fonttheme:
fontsize: 11pt
linkcolor: black
urlcolor: blue
linkstyle: bold
aspectratio: 169
titlegraphic: 
logo:
date:
section-titles: false
toc: false
---


## Today's talk: a computer's perspective on MSK imaging

 \
**1.** What is an **image**?

 \
**2.** Software **bottlenecks** for AI research

 \
**3.** What you can $\BR{expect}$ going forward

 \
 \
I do not have any conflict of interest to disclose.


# What is an image?


## What do you see on a medical image? `\cite{ankle_model}`{=latex}

```{=latex}
\vspace{-.43cm}
\begin{align*}
	\onslide<2->{ \text{1. Pixels} }&&
	\onslide<3->{ \text{2. Anatomy} } &&
	\onslide<4->{ \text{3. Function} }
\end{align*}

\begin{figure}
	\centering %
	\only<1>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/ankles/ankle_3views.png} }%
	\only<2>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/ankles/ankle_3views_pixels.png} }%
	\only<3>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/ankles/ankle_3views_seg.png} }%
	\only<4>{ \includegraphics[height=.7\textheight,width=\textwidth]{images/ankles/Ankle_Close_All.jpg} }%
	\only<5->{ 
		\includegraphics[height=.55\textheight]{images/ankles/ankle_3views_voisinages.png}
		\begin{center}
		Simplifying a bit, each level of analysis corresponds to\\
		a way of \textbf{grouping pixels} with their neighbors.
		\end{center}
		}%
\end{figure}
```



## 1st level: a pixel grid

```{=latex}
	\begin{columns}[t]
		\begin{column}{.45\linewidth}

		\begin{center}
			\vspace*{.4cm}

			\includegraphics[width=.8\linewidth]{images/bitmap/mini_bitmap.png}%

			$\text{N}_\text{x} \times \text{N}_\text{y} \times \text{N}_\text{z}$ array of pixels.
		\end{center}
			
		\end{column}
		\begin{column}{.5\linewidth}

			\textbf{Bitmap} images and volumes:
			\begin{itemize}
				\item \texttt{.bmp}, \texttt{.png}, \texttt{.jpg} 
				\item Standard in \textbf{radiology}.\\[.5cm]
				\item[$+$] Ordered memory structure.
				\item[$+$] Explicit neighborhoods.
				\item[$+$] Fast \textbf{local} filters. \\[.5cm]
				\item[$\rightarrow$] \textbf{Texture} analysis.
				\item[$\rightarrow$] Organ \textbf{segmentation}.
				\item[$\rightarrow$] Pattern \textbf{detection}. 
			\end{itemize}
		\end{column}
	\end{columns}
```


## 2nd level: point clouds and 3D surfaces

```{=latex}
\begin{columns}[t]
	\begin{column}{.45\linewidth}

	\begin{center}
		%\vspace*{1cm}

		\includegraphics[width=.8\linewidth]{images/triangle_mesh.png}%

		$\text{N}_{\text{points}} \times \text{3}$ array of $(\text{x},\text{y},\text{z})$ coordinates.
	\end{center}
		
	\end{column}
	\begin{column}{.5\linewidth}

		\textbf{Clouds of points} ($\pm$ triangles):
		\begin{itemize}
			\item \texttt{.svg}
			\item Standard for \textbf{video games}.\\[.5cm]
			\item[$+$] Compact representation.
			\item[$+$] High precision geometry.
			\item[$+$] \textbf{Easy to deform}. \\[.5cm]
			\item[$\rightarrow$] \textbf{3D visualization}.
			\item[$\rightarrow$] Anatomical \textbf{atlas}.
			\item[$\rightarrow$] \textbf{Shape} analysis.
		\end{itemize}
	\end{column}
\end{columns}	
```

## 3rd level: biomechanical and/or physiological model `\cite{ankle_model}`{=latex}

```{=latex}
\begin{columns}[t]
	\begin{column}{.45\linewidth}

	\begin{center}
		%\vspace*{.5cm}

		\includegraphics[height=5cm]{images/ankles/Ankle_Close_All.jpg}%

		Volumetric mesh, \\graph of interactions.
	\end{center}
		
	\end{column}
	\begin{column}{.5\linewidth}

		\textbf{Mechanical/biological model}:
		\begin{itemize}
			\item Finite elements, networks.
			\item Standard for \textbf{CAD}.\\[.5cm]
			\item[$+$] Prior \textbf{knowledge}.
			\item[$+$] \textbf{Robust} to noise.
			\item[$+$] \textbf{Realistic} behaviour. \\[.5cm]
			\item[$\rightarrow$] \textbf{Physiological} interpretation.
			\item[$\rightarrow$] \textbf{Infer} what cannot be seen (stress).
			\item[$\rightarrow$] \textbf{Simulate} a surgery.
		\end{itemize}
	\end{column}
\end{columns}
```


## Strengths and weaknesses of these image formats

Looking for the **neighbors** of a point in 3D space?

- On a **grid** : $\textcolor{green!60!black}{\text{read}}$ adjacent memory cells.
- With $\text{N}$ **points** $(\text{x},\text{y},\text{z})$ : $\text{\textcolor{red!60!black}{computation}}$ of $\text{N}$ distances.


 \
Want to **rotate** a bone by 10°?

- On a **grid** : $\text{\textcolor{red!60!black}{artifacts}}$, loss of details, transfers between memory cells.
- With $\text{N}$ **points** $(\text{x},\text{y},\text{z})$ : $\text{\textcolor{green!60!black}{simple}}$ arithmetics on the coordinates.

`\begin{center} ~\\`{=latex}
Computational **speed** $\Longleftrightarrow$ Training on $\BR{large datasets}$.
`\end{center}`{=latex}



## To summarize

AI = **statistical regression** method + relevant **computational model**.

In medical imaging, we represent patient data as:

1. A 2D or 3D **pixel grid**.
2. An array of $(\text{x},\text{y},\text{z})$ **coordinates**.
3. A **web** of complex interactions.
4. All three at once!

`\begin{center}`{=latex}
In most cases, we define a large `\textcolor{red!80!black}{\textbf{structured formula}}`{=latex}:

```{=latex}
\vspace*{-.5cm}
\begin{align*}
	\text{image} \xrightarrow{~~~\text{F}~~~} \text{F}\,(\text{image}) \simeq \text{diagnostic}
\end{align*}
```

**F** is a parametric computing **architecture** \
$\simeq$ **model** to fit $\simeq$ **network** to train.

`\end{center}`{=latex}




# Software bottlenecks for AI research

## The AI revolution is driven by gaming computers

**Digital images** and machine **learning** have been studied for **decades**. \
**Breakthrough** in 2010-15 : using $\BR{PlayStations}$ to do $\BR{science}$ became **easy**.

::: columns
:::: {.column width=70%}

 \
 \
Research effort at all levels towards:

- Increasingly powerful **computers**.
- Increasingly convenient **software toolkits**.
- Increasingly relevant **models**.

 \
 \
**Spectacular results** in a few applications \
$\Longrightarrow~~$ massive $\BR{investments}$, industry + governments.

::::
:::: {.column width=30%}
`\begin{center}`{=latex}

![](images/ampere.jpg){height=4cm}

 \
**7,000 cores** on a GPU.

`\end{center}`{=latex}
::::
:::


## For grid images: a mature ecosystem



`\begin{center}`{=latex}

![](images/computer_vision.pdf){width=100%}

Main motivation for AI in 2012-2022: $\BR{self-driving cars}$. \
Key challenges: **segment** the environment, **detect** other actors.

Two full software suites to manipulate $\BR{images as grids of pixels}$: \
TensorFlow (Google) and PyTorch (Facebook-Meta).

`\end{center}`{=latex}


## To go beyond prototypes, AI engineers need a full software suite

```{=latex}
\vspace*{.5cm}

\centerline{
\begin{tabular}{c@{~~}c@{~~$+$~~}c@{~~$+$~~}c@{~~$\Longrightarrow$~~}c}
\BR{Graphics:} & \textcolor{red!50!black}{Printer} & \textcolor{red!50!black}{Driver} & \BR{Photoshop} & \textcolor{red!50!black}{Illustrations} \\[1cm]
\makecell{\textbf{Tabular data:}} & GPU & \textbf{cuBLAS} & \makecell{ \textbf{PyTorch} \\ TensorFlow } 
& \makecell{\textbf{``Classical''} \\ neural networks} \\[1cm]
\makecell{\textbf{Pixel grids:}} & GPU & \textbf{cuDNN} & \makecell{ PyTorch \\ TensorFlow } 
& \makecell{\textbf{Convolutional} \\ neural networks} \\[1cm]
\makecell{\textbf{Point clouds}\\\textbf{and graphs~:}} & GPU & \textbf{CUDA} & 
\BR{??}
& \makecell{\textbf{Geometric} \\ neural networks}
\end{tabular}
}
```


## For point clouds and graphs: work in progress


::: columns
:::: {.column width=50%}
`\begin{center}`{=latex}
![](images/arteries.png){height=5.5cm}

Brain arterial network. \
How do we **process this object**?
`\end{center}`{=latex}
::::
:::: {.column width=50%}

 \
An ecosystem under construction: \
 \

- **KeOps** : since 2017

  - Fast learning with $\BR{point clouds}$. `\vspace*{.2cm}`{=latex}
  
- **PyG** : since 2018

  - Fast learning with $\BR{graphs}$.  `\vspace*{.2cm}`{=latex}

- **FEniCSx** and **PhiFlow** : since 2018

  - Fast learning with  $\BR{physics}$.  `\vspace*{.2cm}`{=latex}

- **PyVista** and **Vedo** : since 2019

  - $\BR{3D visualisation.}$  `\vspace*{.2cm}`{=latex}

- **scikit-shapes**: released soon
  - Easy $\BR{morphometrics.}$ 
    \

::::
:::

## Conclusion

- **Gaming computers** (GPUs) are the workhorses of AI. \
  A $\BR{full}$ **software suite** is required to rein in these machines.

- Since 2015, **medical imaging** rides a wave of investment \
  from the **FAANG** for $\BR{natural}$ image processing. \
  \
  Breakthroughs: **segmentation**, **texture** analysis and lesion **detection**. \
  
  
- What about **surgical** planning, **morphometrics**, **vascular** analysis... ? \
  \
  An **investment in the** $\BR{numerical foundations}$ of the field is under way. \


# References